===========================================
LHCb Development Tools | Formatting pluggin
===========================================

Purpose
=======
This python package exists to add formatting-related subcommands to the already-existing lb-dev command